set_yticks — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# set_yticks

EBSPlot.set_yticks(major: float | None = None, minor: float | None = None, interval: List[float] | None = None)

  A method to set the y ticks

  Parameters:

    - major (float, optional) – A float to set the major tick locator, by default None

    - minor (float, optional) – A float to set the the minor tick Locator, by default None

    - interval (List[float], optional) – The interval of the ticks, by default None